@@ -17,18 +17,17 @@
 #include <QSequentialAnimationGroup>
 
 HighlightAnimation::HighlightAnimation(const QLineF &line)
-	: QGraphicsLineItem(line)
+    : QGraphicsLineItem(line)
 {
-	setPen(QPen(Settings::highlightColor(), 8.0, Qt::SolidLine, Qt::RoundCap));
+    setPen(QPen(Settings::highlightColor(), 8.0, Qt::SolidLine, Qt::RoundCap));
 
-	QPropertyAnimation* animation = new QPropertyAnimation(this, "opacity", this);
-	animation->setStartValue(1.0);
-	animation->setEndValue(0.0);
-	QSequentialAnimationGroup* animGroup = new QSequentialAnimationGroup(this);
-	animGroup->addPause(1000);
-	animGroup->addAnimation(animation);
-	animGroup->start(QAbstractAnimation::DeleteWhenStopped);
-	connect(animGroup, SIGNAL(finished()), this, SLOT(deleteLater()));
+    QPropertyAnimation *animation = new QPropertyAnimation(this, "opacity", this);
+    animation->setStartValue(1.0);
+    animation->setEndValue(0.0);
+    QSequentialAnimationGroup *animGroup = new QSequentialAnimationGroup(this);
+    animGroup->addPause(1000);
+    animGroup->addAnimation(animation);
+    animGroup->start(QAbstractAnimation::DeleteWhenStopped);
+    connect(animGroup, &QSequentialAnimationGroup::finished, this, &HighlightAnimation::deleteLater);
 }
 
-#include "highlightanimation.moc"
