@@ -12,16 +12,16 @@
 
 #include "ui_newgamewidget.h"
 
-#include <kdialog.h>
+#include <QDialog>
 
-class NewGameDialog : public KDialog, public Ui::NewGameWidget
+class NewGameDialog : public QDialog, public Ui::NewGameWidget
 {
-	Q_OBJECT
-	public:
-		explicit NewGameDialog(QWidget* parent = 0);
-	
-	public slots:
-		void adjustEnabledUsers(int);
+    Q_OBJECT
+public:
+    explicit NewGameDialog(QWidget *parent = 0);
+
+public Q_SLOTS:
+    void adjustEnabledUsers(int);
 };
 
 #endif // NEWGAMEDIALOG_H
